.. gcm-filters documentation master file, created by
   sphinx-quickstart on Tue Jan 12 09:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to particle-tracking-manager's documentation!
=====================================================

Installation
------------

To install from conda-forge:

   conda install -c conda-forge particle-tracking-manager

To install from PyPI:

   pip install particle-tracking-manager

.. toctree::
   :maxdepth: 3
   :hidden:
   :caption: Examples and demos

   quick_start
   tutorial
   ocean_models
   scenario_details
   configuration
   plots


.. toctree::
   :maxdepth: 3
   :hidden:
   :caption: Developer docs

   api
   whats_new
   GitHub repository <https://github.com/axiom-data-science/particle-tracking-manager>



.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
